#Discussion

Our findings from 232 EBOV Makona genomes sampled in Sierra Leone over 7 months during the 2013-2015 EVD outbreak in Western Africa demonstrate the value of continued sequencing throughout an epidemic. We tracked the movement of EBOV throughout Sierra Leone and determined the frequency of EBOV movement into and out of that country. Although it is not unlikely that the virus continued to cross the national borders of Sierra Leone throughout the epidemic, these observations suggest that, at least in late 2014, cross-border introductions were not an important factor in the development of the epidemic. We were unable, however, to draw any conclusions about export to Guinea, since few EBOV sequences from there are currently available.

The sequence data display EBOV Makona evolution in the context of prolonged human-to-human transmission, and provide an updated view of genomic diversity. Based on the rates of nonsynonymous and synonymous changes that are shared or are unique to an individual host, we concluded that purifying selection becomes increasingly effective over time, as it has more opportunity to remove deleterious mutants. 

While the effects of purifying selection in this extended EVD outbreak are clear, these evolutionary changes do not imply that positive selection or adaptation to humans are occurring. Rather, the data suggest that evolutionary changes over time through natural selection is sufficient to remove newly arisen alleles that are less fit in the human environment. To date, no published study has found experimental evidence of selection for alleles beneficial to the virus within the current outbreak. 

It is important to recognize, however, that the long-term human-to-human transmission observed during the 2013-2015 EVD outbreak is historically unique for EBOV. At the beginning of each EVD outbreak, EBOV enters the human population with little or no genetic diversity. In the case of the current EVD outbreak, EBOV has now maintained fitness while expanding across a much larger space of genetic diversity than in previous EVD outbreaks, the largest of which comprised only 318 human infections. This degree of diversity will undoubtedly affect researchers' ongoing efforts to developing or improve improving candidate diagnostics, vaccines, and therapeutics for EVD, many of which are targeting EBOV sequences directly (PCR, nucleic-acid based therapeutics) or indirectly (antibody cocktails).

The mucin-like domain of the EBOV glycoprotein, in contrast to the rest of the EBOV genome, appeared to be under diversifying selection, based on a high ratio of nonsyonymous to synonymous mutations. While not statistically significant because of the small numbers of SNPs in the region, our observation is in agreement with many previous studies \citep{Sanchez_1998, Wertheim_2009}. As the EBOV GP, especially the mucin-like domain, is the target of many antibodies, a plausible hypothesis is that the humoral immune response exerts selective pressure on GP, resulting in an accumulation of nonsynonymous mutations. In support of this hypothesis, regions of GP corresponding to experimentally-determined B cell epitopes are significantly enriched in nonsynonymous, but not in synonymous, variants. There are two important caveats to this analysis: (1) these epitopes are determined *in vitro* and therefore may not be epitopes *in vivo* if they are not immunodominant, and (2) there is no experimental evidence to suggest that the majority of observed variants disrupt antibody binding to these epitopes. 

While further experimental testing is required to validate an immune evasion hypothesis, we have highlighted a few prime candidates to consider. Genomes from three samples share a threonine-to-alanine mutation at GP amino acid position 485, a position that is conserved across all species of the Ebolavirus genus. This position is indispensable for binding of the protective antibody 14G7 \cite{olal_2012}; the observed variant at this site may therefore be the result of escape from antibody-mediated selection. Additionally, two samples each possess multiple mutations within a single experimental B cell epitope in GP, which are likely to evade antibody recognition if those regions are relevant epitopes *in vivo*.

Intriguingly, the two samples with multiple mutations within a single B cell epitope each possess a distinct short stretch littered with T-to-C transitions, a phenomenon also observed in Tong et al \cite{Tong_2015}. Excessive T-to-C and A-to-G mutation of virus genomes has been observed previously as a result of adenosine deaminases acting on RNA (ADARs, \cite{Gelinas_2011, Zahn_2006, Carpenter_2009}). When acting on viral genomic RNA, ADARs cause a pattern of excess A-to-G transitions that are represented by T-to-C transitions in our data set. These transitions are known to occur either promiscuously within 200 nucleotide stretches, or in a sequence-specific manner; therefore, we investigated both possibilities. While only five of the 318 sequences in our dataset contained obvious T-to-C stretches, we showed that the top 5% of sequences by sequence divergence, excluding the 5 sequences with T-to-C stretches, were also moderately enriched for T-to-C transitions across the genome. The remaining 95% of sequences appeared to show no enrichment. We do not know if this phenomenon is caused by ADAR acting upon genomic RNA, as we cannot exclude the possibility of bias by the EBOV RNA polymerase or other effects. Additionally, it is yet unclear if these T-to-C mutations have an anti-viral or other effect on viral fitness. These questions open avenues of research into molecular mechanisms shaping EBOV evolution.

The results of some of the specific genome analysis methods that we introduced here, while promising, will require denser EBOV genome sampling to yield sufficient information to influence the EVD outbreak response. Among these methods is transmission analysis, which could prove valuable for improved understanding of hospital-based transmissions and therefore for improved infection control. Inference of the ancestral genetic state is often straightforward, with clear patterns of new variations layering on previously existing variations; viruses that appear to be descended from others in the same data set are separated only by new mutations that are seen nowhere else in the data set. This kind of genetic relationship does not guarantee a transmission relationship between two patients, since many viruses can share identical genomes. However, since viruses with identical genomes are often epidemiologically related \citep{Gire_2014}, we can infer that viruses that appear to descend from other viruses in our data set are either in or epidemiologically close to the same transmission chain.

Unfortunately, long delays of shipping samples from the field and required changes to the EBOV inactivation protocol caused severe degradation of many samples, which prevented identification of variants and transmission analysis. This loss should serve as a reminder that standardized and optimized protocols for sample collection, virus deactivation, and shipment are crucial for a rapid worldwide response to any new infectious disease outbreak. An important future research effort will be aimed at understanding which certified EVD sample deactivation protocols are best suited for high-quality genomic sequencing. Complications with sample shipment also emphasize the need for establishing in-country sequencing capabilities either before or at the onset of future EVD outbreaks \citep{Folarin_2014}. .

Beyond coordinated field and experimental responses, a culture of rapid data sharing is critical for teams around the world to have the best current information about a circulating virus or ongoing disease \citep{Yozwiak_2015}. In light of this need, we released all data discussed in this paper publicly as they were generated, beginning in December 2014, well in advance of our own analysis. We have previously described our high-depth sequencing protocols \citep{Matranga_2014} and we are also now making available our computational analysis pipeline, in the hope that they will assist the many laboratories engaged in viral genomic research. As more EBOV genomic data become available, in particular for poorly covered Liberia and Guinea, the scientific community can together obtain a broader picture of transmission and evolution of EBOV Makona during the EVD epidemic.